@@ -4,7 +4,8 @@ covdesign<-function(formel,covs,ENV)
    # number of factor levels for terms from formula
    vars<-attr(terms(formel),"term.labels")
    order<-attr(terms(formel),"order")
-   vars<-vars[order==1]
+            #vars<-vars[order==1]
+   vars<-sort(vars[order==1]) # maybe not necessary to sort names
    levs<-apply(as.matrix(covs[,vars]),2,max) # number of factor levels
 
 
@@ -15,7 +16,8 @@ covdesign<-function(formel,covs,ENV)
 
 
    form<-formula(formel)
-   form.terms<-terms(form, keep.order=TRUE, simplify = TRUE)
+###   form.terms<-terms(form, keep.order=TRUE, simplify = TRUE)
+   form.terms<-terms(form, simplify = TRUE)
    mmat<-model.matrix(form.terms,data=maineffects)  # intercept included
    as.matrix(unique(mmat))
 }
